# View Tempstore Clear

The **View Tempstore Clear** module provides functionality to clean up the temporary storage (tempstore) of any specific view or all views at once. This feature is especially useful for removing unsaved changes in a view, particularly in cases where access to the view settings page is unavailable or when a view is causing errors due to the deletion of required relationships for existing fields or filters.

## Key Features

- **Temporary Storage Cleanup:**
  - Clean up the tempstore of a specific view.
  - Clear tempstore for all views in one go.

- **Form Interface:**
  - A simple form, **Clean up view tempstore**, is provided at the following path:
    - `admin/structure/views/view-tempstore-cleanup`
  - The form includes:
    - A field to enter the machine name of the view to be cleaned up (`View key name`).
    - Two buttons:
      - **Cleanup view by machine name:** Cleans the tempstore for the view specified in the field.
      - **Cleanup all views:** Clears the tempstore for all views.

- **Drush Integration:**
  - The module provides a Drush command to clear the tempstore.
  - **Command Details:**
    - **Command:** `views:tempstore:clean`
    - **Aliases:** `view-clean`
    - **Usage Examples:**
      ```
      # Clean tempstore for a specific view:
      drush views:tempstore:clean view_name

      # Clean tempstore for all views (default):[all]
      drush views:tempstore:clean
      ```

- **Drupal Console Support:**
  - The module also supports executing the cleanup function via the Drupal Console.
  - The parameters for the Drupal Console command are identical to those used in Drush:
    ```
    # Clean tempstore for a specific view:
    drupal views:tempstore:clean view_name

    # Clean tempstore for all views (default):[all]
    drupal views:tempstore:clean
    ```

## Use Cases

- **Error Resolution:**
  - Resolve issues caused by deleted relationships or unsaved changes in a view.
- **Quick Cleanup:**
  - Clean up tempstore data without needing direct access to the view settings page.

## Installation

1. Place the module in the `modules/custom` directory of your Drupal installation.
2. Enable the module:
   ```
   drush en view_tempstore_clear
   ```

## Usage

### Using the Admin Interface
1. Navigate to **Structure > Views > Clean up view tempstore** (`admin/structure/views/view-tempstore-cleanup`).
2. Use the provided field `View key name` to enter the machine name of a specific view.
3. Choose one of the two available buttons:
  - **Cleanup view by machine name:** Cleans the tempstore for the specified view.
  - **Cleanup all views:** Clears the tempstore for all views.

### Using Drush
Run the following command to clean the tempstore:
```
# Clean tempstore for a specific view:
drush views:tempstore:clean view_name

# Clean tempstore for all views (default):[all]
drush views:tempstore:clean
```

### Using Drupal Console
The command syntax for Drupal Console is the same as Drush:
```
# Clean tempstore for a specific view:
drupal views:tempstore:clean view_name

# Clean tempstore for all views (default):[all]
drupal views:tempstore:clean
```

## A Word of Caution
If you happen to have a view with the machine name `all`, attempting to clean it will result in clearing the tempstore for **all views**! ¯\_(ツ)_/¯

## Author
Module developed and maintained by **Borg_git**.

---
Feel free to contribute or report issues to improve the functionality of this module!

