<?php

namespace Drupal\view_tempstore_clear;

use Drupal\Core\Entity\EntityTypeManager;
use Drupal\Core\Messenger\MessengerInterface;
use Drupal\Core\TempStore\SharedTempStoreFactory;

class CleanUpViewTempstore {

  /**
   * The tempstore object.
   *
   * @var \Drupal\Core\TempStore\SharedTempStore
   */
  protected $view;

  /**
   * The query object.
   *
   * @var \Drupal\Core\Entity\Query\QueryInterface
   */
  protected $query;

  /**
   * The messenger service.
   *
   * @var \Drupal\Core\Messenger\MessengerInterface
   */
  public $messenger;

  /**
   * Constructs a new CleanUpViewTempstore object.
   *
   * @param \Drupal\Core\TempStore\SharedTempStoreFactory $tempstore
   *   The tempstore object.
   * @param \Drupal\Core\Entity\EntityTypeManager $query
   *   The query object.
   * @param \Drupal\Core\Messenger\MessengerInterface $messenger
   *   The messenger service.
   *
   * @throws \Drupal\Component\Plugin\Exception\InvalidPluginDefinitionException
   * @throws \Drupal\Component\Plugin\Exception\PluginNotFoundException
   */
  public function __construct(SharedTempStoreFactory $tempstore, EntityTypeManager $query, MessengerInterface $messenger) {
    $this->view = $tempstore->get('views');
    $this->query = $query->getStorage('view')->getQuery();
    $this->messenger = $messenger;
  }


  /**
   * Service to clear view tempstore by key name or all views.
   *
   * @param string $name
   *   View machine name argument.
   *
   * @throws \Drupal\Core\TempStore\TempStoreException
   */
  public function viewTempstoreCleanup(string $name) {
    $views = $this->query->execute();

    if (empty($name)) {
      $this->messenger->addError(t("Set view machine name or 'all' for select all views."));
    }
    elseif ($name === 'all') {
       foreach ($views as $view) {
         $this->view->delete($view);
       }
      $this->messenger->addMessage(t('All view tempstores cleared.'));
    }
    elseif (!in_array($name, $views)) {
      $this->messenger->addWarning(t("View by machine name '" . $name . "' not found."));
    }
    else {
      $this->view->delete($name);
      $this->messenger->addMessage(t("View tempstore '" . $name . "' cleared."));
    }
  }
}
